#!/usr/bin/perl -w
#
# Convert a DGC file to an XML file suitable for use by bleb.org/tv/

use strict;

my $loc  = $ARGV[0] or die "syntax: $0 <url or filename>\n";
my $data = '';

# -- Get data ---------------------------------------------------------
#
if (-f $loc) {
    open(IN, "<$loc") or die "unable to open file $loc: $!\n";
    while (<IN>) { $data .= $_; }
    close(IN) or die "unable to close file $loc: $!\n";

} else {
    use LWP::Simple;
    $data = get($loc) or die "unable to fetch DGC file\n";
}

# -- Process data ----------------------------------------------------
#
print "<listings source=\"DGC\">\n";

my $section = '';
while ($data =~ /^(.*?)$/mg) {
    my $line = $1;
    $line =~ s/[\r\n]+//g;
    $line =~ s/^\s+//g;
    $line =~ s/^\s*//g;
    next if $line =~ /^#/;

    if ($line =~ /^\[(\w+)\]$/) {
        print "  </$section>\n" if $section;
        $section = $1;
        my $id = $section =~ s/(\d+)$// ? " id=\"$1\"" : '';
        print "  <$section$id>\n";

    } elsif ($line =~ /^(\w+)\s*=\s*(.*)$/) {
        my ($k, $v) = (lc($1), $2);
        next if $k =~ /^template/;

        my $id = $k =~ s/(\d+)$// ? " id=\"$1\"" : '';
        print "    <$k$id>$v</$k>\n";
    }
}
print "  </$section>\n" if $section;
print "</listings>\n";
exit;

